@@ -45,12 +45,13 @@ def watch(runtime, data):
         if not runtime[r.PLAYER_ARGS_OVERRIDE]:
             args = player_args(runtime, data, data[database.PLAYER_ARGS])
         else:
-            args = player_args(runtime, data, runtime[r.PLAYER_ARGS_OVERRIDE])
+                args = player_args(runtime, data, runtime[r.PLAYER_ARGS_OVERRIDE])
 
-        print("Episode #{}\n        {}\n        {}\n[[enter] - watch, [^c] - break]".format(
-            episode, 
-            os.path.split(file)[-1],
-            args))
+        print(r.format("{c_title}Episode {c_ep_number}{bold}#{episode}{endc}\n        {c_path}{path}\n        {c_args}{args}\n{endc}{c_control}[[enter] - watch, [^c] - break]", 
+            episode=episode, 
+            path=os.path.split(file)[-1],
+            args=args,
+            ))
         try:
             input()
         except KeyboardInterrupt:
